.. :changelog:

History
-------
0.2.0 (2023-02-09)
++++++++++++++++++

* First release on PyPI
* NEW FEATURE: dict possible input for data
* NEW FEATURE: argument progress_bar to disable progress_bar

0.1.2 (2023-02-02)
++++++++++++++++++

* FIX: correcting normalization of 1D posteriors (credit to Alexander Charles Tikam)

0.1.1 (2022-11-24)
++++++++++++++++++

* FIX: Bug in the number of digits

0.1.0 (2022-10-31)
++++++++++++++++++

* First release on Gitlab.
